# -*- coding: utf-8 -*-

import tornadoez
import tornadoez.web

class DemoHandler(tornadoez.web.RequestHandler):
    def get(self):
        self.write("Hello world")


handlers = [(r"/", DemoHandler)]





# -*- coding: utf-8 -*-

##################
# Note:
# This file was auto create by cabric, don't edit this file
# It will be always overwrite.
#########


from cliez.loader import ArgLoader
import tornadoez
import tornadoez.web
import tornado.ioloop
import tornado.web


from demo import settings
from demo.handlers import handlers


if __name__ == "__main__":
    from datetime import datetime

    a = ArgLoader((
        ('Usage app.py port',),
        '',
        '',
        'Options:',
        ('--debug', 'debug flag'),
        ('--help', 'print help document', '-h'),
    ))

    try:
        port = int(a.argv[1])
    except:
        port = 9001

    debug = a.options.get('--debug') or False

    print("[tornado]:demo start, bind port {}, begin at: {}.".format(port, datetime.now()))

    settings_debug = None
    if debug:
        print("[tornado]:demo debug mode enabled.")
        settings_debug = settings.dev
        pass

    default_settings = tornadoez.web.build_settings(settings.pro, __file__, debug=settings_debug)
    tornadoez.settings = default_settings

    application = tornado.web.Application(handlers, **default_settings)
    application.listen(port)
    tornado.ioloop.IOLoop.instance().start()



# -*- coding: utf-8 -*-

##################
# Note:
# This file was auto create by cabric, don't edit this file
# It will be always overwrite.
#########


import tornado.wsgi
import tornadoez
import tornadoez.web
from demo import settings
from demo.handlers import handlers


default_settings = tornadoez.web.build_settings(settings.pro, __file__)
tornadoez.settings = default_settings
application = tornado.web.Application(handlers, **default_settings)
app = tornado.wsgi.WSGIAdapter(application)




# -*- coding: utf-8 -*-

from demo import config


def pro():
    """
    for production
    :return:
    """
    return {}


def dev():
    """
    for development
    :return:
    """
    return {}


def ci():
    """
    for Continuous integration
    :return:
    """

    return {}





# -*- coding: utf-8 -*-


# used for python web world, django and tornado

from fabric.api import *
from fabez.lib import read_template
import shutil

import os


def web_fetch_app():
    """
    get current apps
    return:
    """
    current_path = os.getcwd()
    files = os.listdir(current_path)

    filters = ['web', 'config', 'docs', 'resources', 'templates', 'static', 'sketch']

    apps = [v for v in files if v not in filters and os.path.isdir(v) and not v.startswith('_') and not v.startswith('.')]

    return apps, current_path


def web_sync_config():
    """
    sync config.py files to web-app dirs
    :return:
    """
    apps, root = web_fetch_app()
    for v in apps:
        shutil.copy('config.py', os.path.join(root, v, 'config.py'))

    pass


def web_create_app(app_name):
    """
    create tornado style web app
    :param app_name:
    :return:
    """
    root = os.getcwd()
    current_path = os.path.join(root, app_name)

    # limit for file
    if os.path.isfile(current_path):
        raise Exception("{} is a file,can't create app,please set another name or delete it.".format(app_name))

    # create dir when not exist
    if not os.path.exists(current_path):
        os.mkdir(current_path, mode=0755)

    static_path = os.path.join(current_path, 'static')
    template_path = os.path.join(current_path, 'templates')
    # create dir
    for v in [static_path, template_path]:
        if not os.path.exists(v):
            os.mkdir(v, mode=0755)

    tpls = ['web/app.py', 'web/wsgi.py']

    for tpl in tpls:
        buf = read_template(tpl)

        buf = buf.replace('Demo', app_name.capitalize()).replace('demo', app_name)
        file_path = os.path.join(current_path, os.path.basename(tpl))

        with open(file_path, 'w') as fh:
            print >> fh, buf

    safe_tpls = ['web/settings.py', 'web/config.py', 'web/handlers.py', 'web/__init__.py']
    for tpl in safe_tpls:
        file_path = os.path.join(current_path, os.path.basename(tpl))
        if not os.path.exists(file_path):
            buf = read_template(tpl)

            buf = buf.replace('Demo', app_name.capitalize()).replace('demo', app_name)
            with open(file_path, 'w') as fh:
                print >> fh, buf

    pass


def web_sync_static(clean=False):
    """
    this feature is a wrapper for  django manage.py collectstatic
    :return:
    """

    python_path = None

    pypy = local('which pypy', capture=True)
    python3 = local('which python3', capture=True)

    if pypy:
        python_path = pypy
    elif python3:
        python_path = python3
    else:
        python_path = 'python'

    cmd = '{} manage.py collectstatic  --noinput'.format(python_path)

    if clean:
        cmd += ' -c'

    os.system(cmd)

    pass

